aboutsummaryrefslogtreecommitdiffstats
path: root/skeletons/xer_decoder.h
diff options
context:
space:
mode:
Diffstat (limited to 'skeletons/xer_decoder.h')
-rw-r--r--skeletons/xer_decoder.h13
1 files changed, 8 insertions, 5 deletions
diff --git a/skeletons/xer_decoder.h b/skeletons/xer_decoder.h
index 1c26ef79..c3df005d 100644
--- a/skeletons/xer_decoder.h
+++ b/skeletons/xer_decoder.h
@@ -70,11 +70,14 @@ ssize_t xer_next_token(int *stateContext, void *buffer, size_t size,
* This function checks the buffer against the tag name is expected to occur.
*/
typedef enum xer_check_tag {
- XCT_BROKEN, /* The tag is broken */
- XCT_UNEXPECTED, /* The tag is fine, but unexpected */
- XCT_OPENING, /* This is the opening <tag> */
- XCT_CLOSING, /* This is the closing </tag> */
- XCT_BOTH, /* This is the opening and closing tag <tag/> */
+ XCT_BROKEN = 0, /* The tag is broken */
+ XCT_OPENING = 1, /* This is the <opening> tag */
+ XCT_CLOSING = 2, /* This is the </closing> tag */
+ XCT_BOTH = 3, /* This is the <modified/> tag */
+ XCT__UNK__MASK = 4, /* Mask of everything unexpected */
+ XCT_UNKNOWN_OP = 5, /* Unexpected <opening> tag */
+ XCT_UNKNOWN_CL = 6, /* Unexpected </closing> tag */
+ XCT_UNKNOWN_BO = 7, /* Unexpected <modified/> tag */
} xer_check_tag_e;
xer_check_tag_e xer_check_tag(const void *buf_ptr, int size,
const char *need_tag);